# Design Notes

## Reason for existence

Furo exists because, at the time of writing, no existing Sphinx documentation theme quite fit what I wanted. The rough structural elements I wanted were:

- Three-column layout, for proper in-page navigation.
- Clear navigational sidebar.
- Good search.
- Good typography.
- Good looking design.

Every existing theme either didn't check all of the boxes above, or tried to do too many things at the same time. There were a few that came close, but nothing really felt quite polished to me.

## "Guiding" ideas

Furo's design follows a few of the ideas I've had discovered over the course of browsing the existing documentation themes across ecosystems and static site generators.

- Focus _must_ be on the content.
- More stuff is not more good.
- Graceful degradation is important, so are niceties.
- Simple and good enough, is more than sufficient.
- This is for the 80% -- don't need to cover all possible usecases.
